#!/bin/bash -f
#
SCRIPTHOME="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
SCRIPTHOME=$PWD

unset FTP_PROXY
unset ALL_PROXY
unset HTTPS_PROXY
unset HTTP_PROXY
export NO_PROXY=localhost

# ulimit -Sc unlimited

ARGS=$*
APP="t1"
KVER=3.2
PORT="12346"
REBUILD=""
TRAP=""
OP=""
SHM=1
LOG=0
POOL=0
POOLMIN=1
LOGS="/tmp/t1"
LAYOUT="blackberry"
INSTANCE=0
MEM=0
SYSTEM="qa"
REGION="dev"
HOST:""

export SHELL=/bin/bash
export QPRELOAD=/export/home/kdb/lib/libhugetlbfs.so
ENVF=/export/home/kdb/ENV
if [ -e $ENVF ] && [ -s $ENVF ] ; then
  source $ENVF
fi

args=$(getopt -l "app,kver,rebuild,trap,port,pool,poolmin,system,region,host,shm,log,layout,mem,instance,start" -o "k:v" -- "$@")

while [ $# -ge 1 ]; do
    case "$1" in
        --)
            # No more options left.
            shift
            break
            ;;
         -k|--kver)
            KVER="$2"
            shift
            ;;
         -v|--app)
            APP="$2"
            shift
            ;;
	--rebuild)
	    REBUILD="$2"
            shift
	    ;;
	--trap)
	    TRAP="$2"
            shift
	    ;;
	--pool)
	    POOL="$2"
            shift
	    ;;
	--poolmin)
	    POOLMIN="$2"
            shift
	    ;;
	--port)
	    PORT="$2"
            shift
	    ;;
	--mem)
	    MEM="$2"
            shift
	    ;;
	--system)
	    SYSTEM="$2"
            shift
	    ;;
	--region)
	    REGION="$2"
            shift
	    ;;
	--host)
	    HOST="$2"
            shift
	    ;;
	--log)
	    LOG="$2"
            shift
	    ;;
	--shm)
	    SHM="$2"
            shift
	    ;;
	--layout)
	    LAYOUT="$2"
            shift
	    ;;
	--instance)
	    INSTANCE="$2"
            shift
	    ;;
	--logs)
	    LOGS="$2"
            shift
            ;;
        --start)
            OP="start"
            shift
            ;;
    esac
    shift
done

if [ -z "$APP" ] || [ "$OP" == "" ] ; then
    echo "Bad/missing arguments: $0 $ARGS"
    echo "Missing one of: OP '$OP' or -A '$APP'" 
    echo "Usage: $0 -A appname [-P startport]"
    exit -1
fi

THIRD_PARTY=/export/home/kdb/thirdparty
export RLWRAP="/export/home/kdb/bin/rlwrap -H /dev/null"
export QLIC="$THIRD_PARTY/kx/licenses/licenses2014/generic"
export QHOME="$THIRD_PARTY/kx/$KVER"

export PATH="/export/home/kdb/bin:$QHOME/l64:/sbin:/usr/sbin:/bin:/usr/bin:$THIRD_PARTY/tibrv/tibrv_8.0/bin"
# export PATH="/export/home/kdb/bin:$QHOME/l64:/sbin:/usr/sbin:/bin:/usr/bin:/dat/tibrv/linux/8.0/bin"

export LD_LIBRARY_PATH="$QHOME/l64:$THIRD_PARTY/odbc/lib:/apps/kdb/local/lib:/usr/lib64:$THIRD_PARTY/mama/mama_4.0.8e/lib:$THIRD_PARTY/tibrv/tibrv_8.0/lib"

export FREETDSCONF=/export/home/kdb/env/freetds.conf

echo "APP: $APP"
echo "QHOME: $QHOME"
echo "QLIC: $QLIC"
echo "PATH: $PATH"
echo "LD_LIBRARY_PATH: $LD_LIBRARY_PATH"
echo "APP: $APP"
echo "SCRIPTHOME: $SCRIPTHOME"
echo "PORT: $PORT"

APP_HOME="$SCRIPTHOME"/$APP
cd $APP_HOME
echo "PWD: $PWD"
echo "OP: $OP"
echo "SHM: $SHM"
echo "POOL: $POOL"
echo "INSTANCE: $INSTANCE"

startt1 () {
    OPTS=""
    OPTS1=""
    mv /tmp/$t1.${INSTANCE}.start.log /tmp/$t1.${INSTANCE}.start_`date +%y.%m.%d.%H:%M`.log
    touch /tmp/$t1.${INSTANCE}.start.log
    chmod 666 /tmp/$t1.${INSTANCE}.start.log
    R="$OPTS screen -c scripts/startscreenrc -L -d -m -t t1 -S t1.$INSTANCE.start $RLWRAP -c $OPTS1 q t1.q -p $PORT \
       	-iPORT    $PORT 	-bSHM     $SHM 		-iINSTANCE $INSTANCE \
	-bMEM     $MEM		-bREBUILD $REBUILD 	-*LAYOUT   $LAYOUT \
 	-bTRAP    $TRAP		-bLOG     $LOG 		-sSYSTEM   $SYSTEM \
	-sREGION  $REGION 	-iPOOL    $POOL 	-iPOOLMIN  $POOLMIN \
	-*LOGS    $LOGS		-sHOST	  $HOST"
    echo "Starting $APP: $R"
    $R
}

dostart () {
    TEST=`curl --noproxy '*' -s http://localhost:$PORT`
    [[ $TEST ]] && echo "$APP already running on $PORT!"
    [[ $TEST ]] && exit -1
    startt1
}

doit () {
    case "$1" in
    start)
        dostart
        ;;
    esac
}

doit $OP

